override_

Function override_ 

pub fn override_<F>(f: F, module_path: &str, name: &str)
Load the Cryptol function name from module_path and install it as an override for the function f. f must be a function definition, not a function pointer or closure, and its signature must match the signature of the Cryptol function. For example, if the Cryptol definition has type [8] -> [8] -> [8], then f must have the signature fn(u8, u8) -> u8, fn(i8, i8) -> u8, or some similar combination.