pub fn uninterp(name: &str)Expand description
Mark the given Cryptol name to be treated as uninterpreted for the duration of the current test.
pub fn uninterp(name: &str)Mark the given Cryptol name to be treated as uninterpreted for the duration of the current test.